Therapeuten — Lino Tera Benutzerhandbuch

# Therapeuten

- Akten
  - Akten anlegen
  - Einzeltherapie
  - Lebensgruppe
  - Meine Akten
  - Datenfelder einer Akte
  - Teilnehmer einer Akte
- Termine erfassen
- Notizen
  - Akten anlegen
- Barzahlungen

Zuletzt aktualisiert am 20.07.2020. Created using Sphinx 3.1.2. Quellcode anzeigen Online Link
Dieses Werk ist lizenziert unter einer Creative Commons Namensnennung - Weitergabe unter gleichen Bedingungen 4.0 International Lizenz.